distlib: Distribution utilities
===============================

Description
-----------

Distribution utilities

License
-------

PSF-2.0

Upstream Contact
----------------

https://pypi.org/project/distlib/

